@@ -10,7 +10,14 @@ from pprint import pprint, pformat
 from . import cfg
 
 
-def RP_to_cfg(key, prefix="", overwrite=True, mappedvalues=[]):
+def inject_in_RP_map(key_name, value):
+    for n, v in cfg.Mappings.items():
+        for m, w in v.items():
+            if key_name not in w:
+                w[key_name] = value
+
+
+def RP_to_cfg(key, prefix="", overwrite=True, mappedvalues=[], check_mapped=False):
     if hasattr(key, "items"):
         for k, v in key.items():
             # remove both * and + that can be present for special IBOX usage
@@ -24,14 +31,26 @@ def RP_to_cfg(key, prefix="", overwrite=True, mappedvalues=[]):
                 setattr(cfg, key_name, v)
                 if key_name not in mappedvalues:
                     cfg.fixedvalues[key_name] = v
+                elif check_mapped:
+                    # key_name is in mapped value and i need to check that cfg.Mappings is complete (Ex. IBOX_SOURCE_OBJ)
+                    inject_in_RP_map(key_name, v)
             # recursively traverse dict
             # keys name are the concatenation of traversed dict keys
             if isinstance(v, dict):
                 for j, w in v.items():
-                    RP_to_cfg({f"{k}{j}": w}, prefix, overwrite)
+                    if j == cfg.IBOX_BASE_KEY_NAME:
+                        # avoid creating cfg entries for IBOX_BASE keys
+                        continue
+                    RP_to_cfg(
+                        {f"{k}{j}": w},
+                        prefix,
+                        overwrite,
+                        mappedvalues=mappedvalues,
+                        check_mapped=check_mapped,
+                    )
 
 
-def merge_dict(base, work):
+def merge_dict(base, work, keep=False):
     if isinstance(work, (str, list)) or not base:
         return work
     keys = dict(list(base.items()) + list(work.items())).keys()
@@ -40,13 +59,16 @@ def merge_dict(base, work):
             # ** is used to replace existing dict instead of merging it
             base[k.replace("**", "")] = work[k]
         elif isinstance(base.get(k), dict) and isinstance(work.get(k), dict):
-            base[k] = merge_dict(base[k], work[k])
+            base[k] = merge_dict(base[k], work[k], keep=keep)
         elif k.endswith("++") and isinstance(work.get(k), list):
             # ++ is used to append elements to an existing key
             try:
                 base[k.replace("++", "")] += work[k]
             except Exception:
                 base[k.replace("++", "")] = work[k]
+        elif k in base and keep:
+            # key is in base and want to keep that value
+            pass
         elif k in work:
             base[k] = work[k]
     return base
@@ -89,29 +111,24 @@ def build_RP():
 
     class Loader(yaml.Loader):
         def __init__(self, stream):
-            # This way for include relative to file with include statement
-            self._root_current = os.path.split(stream.name)[0]
-            # This way for include BASE relative on BASE dir
-            self._root_base = os.path.join(CFG_FILE_INT, "BASE")
-            # This way for include relative on BASE EXT dir
-            self._root_base_ext = os.path.join(CFG_FILE_EXT, "BASE")
+            #            # This way for include relative to file with include statement
+            #            self._root_current = os.path.split(stream.name)[0]
+            # This way for include relative on ibox dir
+            self._root_base = os.path.join(CFG_FILE_INT, cfg.IBOX_BRAND_DIR)
+            # This way for include relative on ibox EXT dir
+            self._root_base_ext = os.path.join(CFG_FILE_EXT, cfg.IBOX_BRAND_DIR)
             # This way for include relative on brand EXT dir
             self._root_brand_ext = os.path.join(CFG_FILE_EXT, brand)
 
-            # try to find out if source file is in a subfolder
-            if self._root_base in self._root_current:
-                suffix = self._root_current.replace(self._root_base, "")
-            elif self._root_base_ext in self._root_current:
-                suffix = self._root_current.replace(self._root_base_ext, "")
-            else:
-                suffix = self._root_current.replace(self._root_brand_ext, "")
-
-            # self.root_current_suffix will be empty if source file is in root
-            self.root_current_suffix = os.path.basename(suffix)
-            if self.root_current_suffix.upper() in cfg.STACK_TYPES:
-                # set to empty even if UPPERCASE subfolders is in
-                # cfg.STACK_TYPES to not be searched for include files
-                self.root_current_suffix = ""
+            #            # find out suffix to use for file included withouth a path (no more used)
+            #            if self._root_base in self._root_current:
+            #                suffix = self._root_current.replace(self._root_base, "")
+            #            elif self._root_base_ext in self._root_current:
+            #                suffix = self._root_current.replace(self._root_base_ext, "")
+            #            else:
+            #                suffix = self._root_current.replace(self._root_brand_ext, "")
+            #
+            #            self.root_current_suffix = os.path.basename(suffix)
 
             self.stream = stream
             super(Loader, self).__init__(stream)
@@ -138,10 +155,9 @@ def build_RP():
                         self._root_base_ext,
                         self._root_brand_ext,
                     ]:
-                        if "/" not in filename and self.root_current_suffix:
-                            # for file in subfolder that include file without a path
-                            # search only in current subfolder
-                            path = os.path.join(path, self.root_current_suffix)
+                        #                        if "/" not in filename:
+                        #                            # for include without a path search only in current subfolder
+                        #                            path = os.path.join(path, self.root_current_suffix)
 
                         contents = self.extractFile(filename, path)
                         if contents:
@@ -262,8 +278,8 @@ def build_RP():
 
         return _recurse(data)
 
-    def read_yaml(file_type, brand, base_dir, stacktype=""):
-        cfg_file = os.path.join(base_dir, brand, stacktype.upper(), f"{file_type}.yml")
+    def read_yaml(file_type, brand, base_dir, stacktype="", prefix=""):
+        cfg_file = os.path.join(base_dir, brand, prefix, stacktype, f"{file_type}.yml")
 
         try:
             with open(cfg_file, "r") as ymlfile:
@@ -274,7 +290,7 @@ def build_RP():
             return {}
 
     def inject_ibox_base(RP, root=""):
-        base_key = "IBOX_BASE"
+        base_key = cfg.IBOX_BASE_KEY_NAME
         for main_key in list(RP.keys()):
             main_key_full = f"{root}{main_key}"
             main_key_value = RP[main_key]
@@ -302,7 +318,13 @@ def build_RP():
                     # need to do it this way to keep the "link" between existing dict keys and values
                     for n, v in merged.items():
                         RP[main_key][resource_key][n] = v
+                # delete IBOX_BASE in RP structure..
                 del RP[main_key][base_key]
+                # ..and in cfg one
+                try:
+                    del getattr(cfg, f"{root}{main_key}")[base_key]
+                except Exception:
+                    pass
 
             if isinstance(main_key_value, dict):
                 inject_ibox_base(main_key_value, root=main_key_full)
@@ -401,23 +423,40 @@ def build_RP():
 
     # End inner methods and begin of main code.
 
-    # envrole type files must be read first
+    # envrole type files must be read first to parse IBoxLoader include/exclude
     yaml_role = [
-        read_yaml(envrole, "BASE", CFG_FILE_INT, stacktype),
-        read_yaml(envrole, "BASE", CFG_FILE_EXT, stacktype),
-        read_yaml(envrole, brand, CFG_FILE_EXT, stacktype),
+        read_yaml(envrole, cfg.IBOX_BRAND_DIR, CFG_FILE_INT, stacktype, cfg.STACKS_DIR),
+        read_yaml(envrole, cfg.IBOX_BRAND_DIR, CFG_FILE_EXT, stacktype, cfg.STACKS_DIR),
+        read_yaml(envrole, brand, CFG_FILE_EXT, stacktype, cfg.STACKS_DIR),
     ]
 
+    if not cfg.YAML_COMMON_NO_BRAND:
+        # speed up multiple stack processing by reading common no brand yaml cfg only once
+        cfg.YAML_COMMON_NO_BRAND += [
+            read_yaml("common", cfg.IBOX_BRAND_DIR, CFG_FILE_INT, prefix="com"),
+            read_yaml("common", cfg.IBOX_BRAND_DIR, CFG_FILE_EXT, prefix="com"),
+        ]
+
     yaml_cfg = {
-        "common": [
-            read_yaml("common", "BASE", CFG_FILE_INT),
-            read_yaml("common", "BASE", CFG_FILE_EXT),
-            read_yaml("common", brand, CFG_FILE_EXT),
-        ],
+        "common": cfg.YAML_COMMON_NO_BRAND
+        # append common brand specific yaml cfg
+        + [read_yaml("common", brand, CFG_FILE_EXT, prefix="com")],
         "type": [
-            read_yaml("TYPE", "BASE", CFG_FILE_INT, stacktype),
-            read_yaml("TYPE", "BASE", CFG_FILE_EXT, stacktype),
-            read_yaml("TYPE", brand, CFG_FILE_EXT, stacktype),
+            read_yaml(
+                "i_type",
+                cfg.IBOX_BRAND_DIR,
+                CFG_FILE_INT,
+                stacktype,
+                cfg.STACKS_DIR,
+            ),
+            read_yaml(
+                "i_type",
+                cfg.IBOX_BRAND_DIR,
+                CFG_FILE_EXT,
+                stacktype,
+                cfg.STACKS_DIR,
+            ),
+            read_yaml("i_type", brand, CFG_FILE_EXT, stacktype, cfg.STACKS_DIR),
         ],
         "role": yaml_role,
     }
@@ -437,10 +476,14 @@ def build_RP():
         pprint(LD_INCLUDED)
         print("########## INCLUDED ####### END #######")
 
-        print("########## FIXEDVALUES ######### START #####")
+        print("########## FIXED_VALUES ######### START #####")
         pprint(cfg.fixedvalues)
-        print("########## FIXEDVALUES ######### END #######")
+        print("########## FIXED_VALUES ######### END #######")
 
-        print("########## MAPPEDVALUES ######### START #####")
+        print("########## MAPPED_VALUES ######### START #####")
+        pprint(cfg.mappedvalues)
+        print("########## MAPPED_VALUES ######### END #######")
+
+        print("########## RP_MAP ######### START #####")
         pprint(cfg.RP_map)
-        print("########## MAPPEDVALUES ######### END #######")
+        print("########## RP_MAP ######### END #######")
