@@ -12,22 +12,30 @@ Conditions = {}
 Mappings = {}
 Resources = {}
 Outputs = {}
+Metadata = {}
 
 OBJS = {}
 
-PATH_INT = os.path.join(os.path.dirname(os.path.realpath(__file__)), "cfg")
+YAML_COMMON_NO_BRAND = []
+
+APP_DIR = os.path.dirname(os.path.realpath(__file__))
+
+PATH_INT = os.path.join(APP_DIR, "cfg")
 PATH_INT = os.path.normpath(PATH_INT)
 
 PATH_EXT = os.path.join(cwd, "cfg")
 PATH_EXT = os.path.normpath(PATH_EXT)
 
+IBOX_BASE_KEY_NAME = "IBOX_BASE"
+
+IBOX_BRAND_DIR = "ibox"
+STACKS_DIR = "stacks"
+
 STACK_TYPES = [
     "agw",
-    "alb",
     "cch",
     "clf",
     "ec2",
-    "ecr",
     "ecs",
     "rds",
     "res",
@@ -93,6 +101,7 @@ EVAL_TROPO_FUNCTIONS_IN_CFG = (
     "Not(",
     "GetAZs(",
     "Tags(",
+    "FindInMap(",
 )
 
 EVAL_PYTHON_FUNCTIONS_IN_CFG = (
@@ -239,6 +248,13 @@ INSTANCE_FAMILY = [
     },
 ]
 
+# currently nearly empty as no more used with newer generations instances
+EPHEMERAL_MAP: {
+    "InstaceEphemeral0": ["m3.medium", "m3.xlarge"],
+    "InstaceEphemeral1": ["m3.xlarge"],
+    "InstaceEphemeral2": [""],
+}
+
 # override previous cfg with an External one
 try:
     with open(os.path.join(cwd, "lib", "cfgExt.py")) as f:
@@ -264,7 +280,6 @@ INSTANCE_LIST = ["default"] + build_instance_list()
 
 # Order is VERY important do not CHANGE it!
 CFG_TO_FUNC = {
-    "MappingClass": {"module": "mappings", "func": "Mappings"},
     "Parameter": {"module": "cloudformation", "func": "CFM_Parameters"},
     "Condition": {"module": "cloudformation", "func": "CFM_Conditions"},
     "Mapping": {"module": "cloudformation", "func": "CFM_Mappings"},
@@ -402,13 +417,17 @@ CFG_TO_FUNC = {
         "func": ("ecs", "Service"),
         "dep": ["SecurityGroups"],
     },
-    "ECSTaskDefinition": {"module": "ecs", "func": "ECS_TaskDefinition"},
+    "ECSTaskDefinition": {"module": "joker", "func": ("ecs", "TaskDefinition")},
     "EFSAccessPoint": {"module": "joker", "func": ("efs", "AccessPoint")},
     "EFSFileSystem": {"module": "efs", "func": "EFS_FileStorage"},
     "ElastiCacheCacheCluster": {
         "module": "joker",
         "func": ("elasticache", "CacheCluster"),
     },
+    "ElastiCacheParameterGroup": {
+        "module": "joker",
+        "func": ("elasticache", "ParameterGroup"),
+    },
     "ElastiCacheReplicationGroup": {
         "module": "joker",
         "func": ("elasticache", "ReplicationGroup"),
@@ -537,6 +556,8 @@ CFG_TO_FUNC = {
         "func": ("scheduler", "Schedule"),
         "dep": ["SecurityGroups"],
     },
+    "SSOPermissionSet": {"module": "joker", "func": ("sso", "PermissionSet")},
+    "SSOAssignment": {"module": "joker", "func": ("sso", "Assignment")},
     "SQSQueue": {"module": "joker", "func": ("sqs", "Queue")},
     "SQSQueuePolicy": {
         "module": "joker",
