@@ -91,6 +91,9 @@ def stack_add_res():
         cfg.template.add_output(v)
     cfg.Outputs.clear()
 
+    cfg.template.set_metadata(get_dictvalue(cfg.Metadata, mapname="Metadata"))
+    cfg.Metadata.clear()
+
 
 def add_obj(obj):
     if isinstance(obj, list):
@@ -348,7 +351,7 @@ def iboxif(if_wrapper, mapname, value):
     return value
 
 
-def get_dictvalue(key):
+def get_dictvalue(key, mapname=""):
     if isinstance(key, list):
         value = [get_dictvalue(k) for k in key]
     elif isinstance(key, dict) and "IBOX_LIST" in key:
@@ -365,9 +368,17 @@ def get_dictvalue(key):
             else:
                 value.append(prop_obj)
     elif isinstance(key, dict):
-        value = {i: get_dictvalue(k) for i, k in key.items()}
+        value = {
+            i: get_dictvalue(k, mapname=f"{mapname}{i}" if mapname else "")
+            for i, k in key.items()
+        }
     elif isinstance(key, str):
-        value = eval(key) if key.startswith(cfg.EVAL_FUNCTIONS_IN_CFG) else key
+        if key.startswith(cfg.EVAL_FUNCTIONS_IN_CFG):
+            value = eval(key)
+        elif mapname and mapname in cfg.mappedvalues:
+            value = get_endvalue(mapname)
+        else:
+            value = key
     else:
         value = key
 
@@ -703,8 +714,11 @@ def auto_get_props(
                 prop_obj = get_dictvalue(key[obj_propname])
             elif prop_class.__name__ == "Tags":
                 prop_obj = _get_obj_tags()
-            elif prop_class.__name__ == "str" and obj_propname == "LifecyclePolicyText":
-                # str but can be represented as dict Ex. ECR LifecyclePolicyText
+            elif prop_class.__name__ == "str" and obj_propname in [
+                "LifecyclePolicyText",
+                "InlinePolicy",
+            ]:
+                # str but can be represented as dict Ex. ECR LifecyclePolicyText, SSO InlinePolicy
                 prop_obj = json.dumps(get_dictvalue(key[obj_propname]))
 
             return prop_obj
@@ -800,6 +814,8 @@ def auto_get_props(
             def _condition(k):
                 for n, v in k.items():
                     n = parse_ibox_key(n)
+                    if v == "IBOX_SKIP":
+                        continue
                     condition = {n: eval(v)}
                     add_obj(condition)
 
@@ -964,10 +980,12 @@ def auto_get_props(
                 lo_resname = lo_conf.get("IBOX_RESNAME", f"{lo_key}{lo_name}")
                 linked_obj["IBOX_RESNAME"] = f"{lo_resname}{lo_for_index}"
 
-                condition = key.get("Condition", getattr(obj, "Condition", None))
-                if condition and not "Condition" in linked_obj:
-                    # automatically add Condition if source obj have it and target not
-                    linked_obj["Condition"] = parse_ibox_key(condition)
+                # automatically add Meta Properties like Condition and UpdateReplacePolicy..
+                for meta_prop in ["Condition", "UpdateReplacePolicy"]:
+                    source_meta_prop = key.get(meta_prop, getattr(obj, meta_prop, None))
+                    if source_meta_prop and not meta_prop in linked_obj:
+                        # ..if source obj have it and target not
+                        linked_obj[meta_prop] = parse_ibox_key(source_meta_prop)
 
                 # assign to louc_cfg lo_key
                 louc_cfg[target_name] = linked_obj
