@@ -38,8 +38,10 @@ def output_template(template, brand=None, envrole=None):
 
 
 def get_template():
-    # save base cfg
+    # save base cfg ..
     cfg_base = cfg.__dict__.copy()
+    # ..and common no brand parsed yaml cfg
+    cfg_base_yaml_common_no_brand = cfg.YAML_COMMON_NO_BRAND
 
     cfg.template = Template()
     RP.build_RP()
@@ -51,6 +53,7 @@ def get_template():
         cfg.OBJS.clear()
         cfg.__dict__.clear()
         cfg.__dict__.update(cfg_base)
+        cfg.YAML_COMMON_NO_BRAND = cfg_base_yaml_common_no_brand
 
     return template
 
@@ -83,8 +86,11 @@ def concurrent_exec(roles, kwargs):
         for future in future_to_role:
             future.cancel()
 
+
 # read CloudFormationResourceSpecification to get CloudFormation Resources Properties
-with open(f"{cfg.PATH_INT}/BASE/CloudFormationResourceSpecification.json", "r") as cfm_res_spec_json:
+with open(
+    os.path.join(cfg.APP_DIR, "aws", "CloudFormationResourceSpecification.json"), "r"
+) as cfm_res_spec_json:
     cfg.cfm_res_spec = json.load(cfm_res_spec_json)
 
 if args.action == "view":
